import React from "react";
// import axios from "axios";

import { useForm } from "../hooks/useForm";
import { Input } from "../input";
import { LocalContext } from "../../utils/localContext";

const FORM_TEMPLATE = {
	email: {
		type: "email",
		name: "email",
		label: "Email",
		placeholder: "Your email",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			}
		},
		touch: false,
		valid: false
	},
	password: {
		type: "password",
		name: "password",
		label: "Password",
		placeholder: "Your password",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			},
			minL: {
				cb: v => v.trim().length < 6
			}
		},
		touch: false,
		valid: false
	}
};

export default ({ submitEvent }) => {
	const { json } = React.useContext(LocalContext);
	const [form, { onChangeHandler, getAllValues, clearEvent }] = useForm(FORM_TEMPLATE);
	// OLD CODE -----------------------------------------
	// validator = (rules, value) => {
	// 	const valid = Object.keys(rules).reduce((prev, elem) => {
	// 		if (prev) return true;
	// 		const check = rules[elem].cb(value);
	// 		if (!prev && check) return check;

	// 		return false;
	// 	}, false);

	// 	return valid;
	// };

	// onChangeHandler = e => {
	// 	const { value, name } = e.target;

	// 	this.setState(prevState => ({
	// 		...prevState,
	// 		form: {
	// 			...prevState.form,
	// 			[name]: {
	// 				...prevState.form[name],
	// 				value,
	// 				touch: true,
	// 				valid: this.validator(prevState.form[name].validate, value)
	// 			}
	// 		}
	// 	}));
	// };
	// -------------------------------------------------------------------------
	// clearEvent = () => this.setState({ form: FORM_TEMPLATE, formValid: false });

	const sendRequest = () => {
		const values = getAllValues();

		submitEvent(values);
	};

	return (
		<form className="auth__auth-form">
			{Object.keys(form).map(el => (
				<Input
					key={el}
					placeholder={form[el].placeholder}
					name={form[el].name}
					value={form[el].value}
					onChange={onChangeHandler}
					label={form[el].label}
					type={form[el].type}
					valid={form[el].valid}
					touch={form[el].touch}
				/>
			))}

			<button onClick={sendRequest} type="button">
				{json.auth.logInButton}
			</button>
			<button onClick={clearEvent} type="button">
				{json.auth.resetButton}
			</button>
		</form>
	);
};
