import React from "react";
import { Link } from "react-router-dom";
import { connect } from "react-redux";

import logo from "../../assets/12345.jpeg";
import { Button } from "../button";
import { withRouter } from "react-router-dom";

import { LocalContext, languages } from "../../utils/localContext";
import { SCCV } from "../../utils/setSCCvariables";

import { ROUTERS } from "../../router";

import "./style.scss";

class Header extends React.Component {
	static contextType = LocalContext;

	constructor(props) {
		super(props);
		// console.log("constructor HEADER");
		this.state = { login: false };
	}

	componentDidMount() {
		console.log("componentDidMount HEADER", this.context);
	}

	logIn = () =>
		new Promise(resolve => {
			setTimeout(() => {
				this.setState(prevState => ({ ...prevState, login: !prevState.login }));
			}, 2000);
		});

	logOut = () =>
		new Promise(resolve => {
			setTimeout(() => {
				this.setState(prevState => ({ ...prevState, login: !prevState.login }));
			}, 2000);
		});

	emptyClick = () => {
		this.props.history.push("/sdasdfhghjutyhtgrfedvgbv");
	};

	changeLanguage = e => {
		this.context.setLanguage(e.target.value);
	};

	changeTheme = e => {
		this.context.setCssVariables(e.target.value);
	};

	renderLi = el => {
		const { location } = this.props;
		return (
			<li key={el.id} className="header__item">
				<Link
					className={
						location.pathname === el.link.path ? "header__link header__link--active" : "header__link"
					}
					to={el.link.path}>
					{el.link.title}
				</Link>
			</li>
		);
	};

	render() {
		const { login } = this.state;
		const { randomNumber, user } = this.props;
		const { json, lang, theme } = this.context;

		if (randomNumber < 50) {
			// return this.props.history.push("/sdasdfhghjutyhtgrfedvgbv");
			// return <Redirect to="/iii33i3i3ii33i3i3i" />;
		}

		// console.log("THIS>, HEADER", this.props);
		return (
			<header className="header">
				<div className="header__logo-box">
					<img src={logo} alt="logo" className="header__logo" />
				</div>

				<div>
					<p>{json.hello}</p>
				</div>

				{user && (
					<div>
						<select value={lang} onChange={this.changeLanguage}>
							{languages.map(el => (
								<option key={el.name} value={el.name}>
									{el.title}
								</option>
							))}
						</select>
						<select value={theme} onChange={this.changeTheme}>
							{Object.keys(SCCV).map(el => (
								<option key={el} value={el}>
									{el}
								</option>
							))}
						</select>
					</div>
				)}

				<nav>
					<ul className="header__list">
						{ROUTERS.map(el =>
							el.link
								? user
									? el.hasAccess && el.hasAccess.some(el => el === user.role) && this.renderLi(el)
									: !el.protected && this.renderLi(el)
								: null
						)}
					</ul>
				</nav>

				<div>Random - {randomNumber}</div>

				<button onClick={this.emptyClick}>404 page</button>

				{login ? (
					<Button className="header__button" onClick={this.logOut}>
						Log Out
					</Button>
				) : (
					<Button className="header__button" onClick={this.logIn}>
						Log In
					</Button>
				)}
				{/* <Button onClick={this.logIn}>Log In</Button> 
			<Button onClick={this.logOut}>Log Out</Button>  */}
			</header>
		);
	}
}

const mapStateToProps = state => ({
	user: state.auth.user
});

export default connect(mapStateToProps)(withRouter(Header));
