import { useState } from "react";

export const useForm = initialValues => {
	const [form, setForm] = useState(initialValues);

	const validator = (rules, value, prevValue) => {
		const valid = Object.keys(rules).reduce((prev, elem) => {
			if (prev) return true;
			const check = rules[elem].cb(value, prevValue[rules[elem].field]);
			if (!prev && check) return check;

			return false;
		}, false);

		return valid;
	};

	const onChangeHandler = e => {
		const { value, name } = e.target;

		setForm(prevState => {
			const allValues = Object.keys(prevState).reduce((prev, elem) => {
				if (name === elem) {
					return { ...prev, [name]: value };
				}
				return { ...prev, [elem]: prevState[elem].value };
			}, {});

			return {
				...prevState,
				[name]: {
					...prevState[name],
					value,
					touch: true,
					valid: validator(prevState[name].validate, value, allValues)
				}
			};
		});
	};

	const getAllValues = () => {
		return Object.keys(form).reduce((prev, elem) => {
			return { ...prev, [elem]: form[elem].value };
		}, {});
	};

	const clearEvent = () => {
		setForm(initialValues);
	};

	return [form, { onChangeHandler, getAllValues, clearEvent }];
};
