import React from "react";

import { useForm } from "../hooks/useForm";
import { Input } from "../input";

const register = {
	email: {
		type: "email",
		name: "email",
		label: "Email",
		placeholder: "Your email",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			}
		},
		touch: false,
		valid: false
	},
	firstName: {
		type: "text",
		name: "firstName",
		label: "First Name",
		placeholder: "Your first name",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			}
		},
		touch: false,
		valid: false
	},
	lastName: {
		type: "text",
		name: "lastName",
		label: "Last Name",
		placeholder: "Your last name",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			}
		},
		touch: false,
		valid: false
	},
	password: {
		type: "password",
		name: "password",
		label: "Password",
		placeholder: "Your password",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			},
			minL: {
				cb: v => v.trim().length < 6
			}
		},
		touch: false,
		valid: false
	},
	confirmPassword: {
		type: "password",
		name: "confirmPassword",
		label: "Confirm Password",
		placeholder: "Your password",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			},
			minL: {
				cb: v => v.trim().length < 6
			},
			match: {
				cb: (v, p) => v !== p,
				field: "password"
			}
		},
		touch: false,
		valid: false
	}
};

export default ({ submitEvent }) => {
	const [form, { onChangeHandler, getAllValues }] = useForm(register);

	// OLD CODE ----------------------------------
	// const [form, setForm] = useState(register);

	// const validator = (rules, value, prevValue) => {
	// 	const valid = Object.keys(rules).reduce((prev, elem) => {
	// 		if (prev) return true;
	// 		const check = rules[elem].cb(value, prevValue[rules[elem].field]);
	// 		if (!prev && check) return check;

	// 		return false;
	// 	}, false);

	// 	return valid;
	// };

	// const onChangeHandler = e => {
	// 	const { value, name } = e.target;

	// 	setForm(prevState => {
	// 		const allValues = Object.keys(prevState).reduce((prev, elem) => {
	// 			if (name === elem) {
	// 				return { ...prev, [name]: value };
	// 			}
	// 			return { ...prev, [elem]: prevState[elem].value };
	// 		}, {});

	// 		return {
	// 			...prevState,
	// 			[name]: {
	// 				...prevState[name],
	// 				value,
	// 				touch: true,
	// 				valid: validator(prevState[name].validate, value, allValues)
	// 			}
	// 		};
	// 	});
	// };
	// ---------------------------------------------------

	const submitEvents = e => {
		e.preventDefault();
		const values = getAllValues();

		submitEvent(values);
	};

	return (
		<form className="auth__auth-form">
			{Object.keys(form).map(el => (
				<Input
					key={el}
					placeholder={form[el].placeholder}
					name={form[el].name}
					value={form[el].value}
					onChange={onChangeHandler}
					label={form[el].label}
					type={form[el].type}
					valid={form[el].valid}
					touch={form[el].touch}
				/>
			))}

			<button onClick={submitEvents}>SUBMIT</button>
		</form>
	);
};
