import React, { Component } from "react";
import { connect } from "react-redux";
import { auth, registration } from "../actions/auth";
import { Redirect } from "react-router-dom";

import AuthForm from "../components/auth";
import RegisterForm from "../components/register";

import { LocalContext } from "../utils/localContext";

class Auth extends Component {
	static contextType = LocalContext;

	state = { auth: true };

	toggleAuthProperty = () => this.setState(prevState => ({ ...prevState, auth: !prevState.auth }));

	render() {
		const { auth } = this.state;
		const { isFetching, registration, user } = this.props;
		const { json } = this.context;

		if (user) return <Redirect to="/" />;

		return (
			<div className="auth">
				<div className="auth__content">
					{isFetching && <div>Loading...</div>}
					{auth ? <AuthForm submitEvent={this.props.auth} /> : <RegisterForm submitEvent={registration} />}
					<div className="auth__buttons-block">
						{auth ? (
							<button onClick={this.toggleAuthProperty}>{json.auth.haveAnAccountQuestion}</button>
						) : (
							<button onClick={this.toggleAuthProperty}>{json.auth.haveAccount}</button>
						)}
					</div>
				</div>
			</div>
		);
	}
}

const mapStateToProps = state => {
	return {
		isFetching: state.auth.isFetching,
		user: state.auth.user
	};
};

export default connect(
	mapStateToProps,
	{ auth, registration }
)(Auth);
