import * as types from "../actionTypes";

const initilalState = {
	list: [],
	item: {
		id: "",
		name: ""
	},
	editMode: false,
	remoteTodo: { fistName: "", lastName: "", age: "", editable: false },
	remoteList: [],
	removeId: "",
	updateId: ""
};

export default (state = initilalState, action) => {
	switch (action.type) {
		case types.ADD_TO_LIST: {
			if (!state.item.name) {
				return state;
			}

			if (state.editMode) {
				return {
					...state,
					list: state.list.map(el => (el.id === state.item.id ? state.item : el)),
					editMode: false,
					item: initilalState.item
				};
			}

			const newItem = {
				...state.item,
				id: Date.now().toString()
			};

			return {
				...state,
				editMode: false,
				item: initilalState.item,
				list: state.list.concat(newItem)
			};
		}
		case types.GET_ALL_LIST: {
			return {
				...state,
				list: action.payload
			};
		}
		case types.UPDATE_ITEM_NAME: {
			return {
				...state,
				item: {
					...state.item,
					name: action.payload
				}
			};
		}
		case types.REMOVE_ITEM: {
			return {
				...state,
				editMode: false,
				list: state.list.filter(el => el.id !== action.payload)
			};
		}
		case types.SET_ITEM_TO_UPDATE: {
			console.log("SET_ITEM_TO_UPDATE", action);
			const item = state.list.find(el => el.id === action.payload);

			return {
				...state,
				editMode: true,
				item
			};
		}

		case types.CHANGE_INPUT_VALUE: {
			const { name, value, type, checked } = action.payload;

			return {
				...state,
				remoteTodo: {
					...state.remoteTodo,
					[name]: type === "checkbox" ? checked : value
				}
			};
		}

		case types.POST_REQUEST: {
			console.log("POST_REQUEST");
			return state;
		}
		case types.POST_REQUEST_SUCCESS: {
			const { data } = action.payload;

			return {
				...state,
				remoteList: state.remoteList.concat({
					...state.remoteTodo,
					id: data.name
				})
			};
		}
		case types.POST_REQUEST_FAIL: {
			console.log("POST_REQUEST_FAIL", action.payload);
			return state;
		}
		case types.GET_ALL_POST_REQUEST: {
			console.log("GET_ALL_POST_REQUEST");
			return state;
		}
		case types.GET_ALL_POST_REQUEST_SUCCESS: {
			const { data } = action.payload;

			const remoteList = Object.keys(data).map(el => ({
				...data[el],
				id: el
			}));
			return { ...state, remoteList };
		}

		case types.GET_ALL_POST_REQUEST_FAIL: {
			console.log("GET_ALL_POST_REQUEST_FAIL", action.payload);
			return state;
		}

		case types.REMOVE_REQUEST: {
			console.log("REMOVE_REQUEST");
			return { ...state, removeId: action.payload };
		}
		case types.REMOVE_REQUEST_SUCCESS: {
			console.log("REMOVE_REQUEST_SUCCESS", action.payload);
			return {
				...state,
				remoteList: state.remoteList.filter(el => el.id !== state.removeId)
			};
		}

		case types.REMOVE_REQUEST_FAIL: {
			console.log("GET_ALL_POST_REQUEST_FAIL", action.payload);
			return state;
		}

		case types.UPDATE_REQUEST: {
			console.log("UPDATE_REQUEST");
			return { ...state };
		}
		case types.UPDATE_REQUEST_SUCCESS: {
			const { data } = action.payload;
			console.log("data", data);
			console.log("UPDATE_REQUEST_SUCCESS", action.payload);
			return {
				...state,
				remoteList: state.remoteList.map(el =>
					el.id === state.updateId ? { ...data, id: state.updateId } : el
				)
			};
		}

		case types.UPDATE_REQUEST_FAIL: {
			console.log("GET_ALL_POST_REQUEST_FAIL", action.payload);
			return state;
		}

		case types.SET_INITIAL_VALUES: {
			return {
				...state,
				updateId: action.payload,
				remoteTodo: state.remoteList.find(el => el.id === action.payload)
			};
		}

		default: {
			return state;
		}
	}
};
