import React from "react";
import { Switch } from "react-router-dom";
import { connect } from "react-redux";
import { getUserByIdRequest } from "./actions/auth";

import Main from "./containers/main";
import Item from "./containers/item";
import AboutUs from "./containers/aboutUs";
import Todo from "./containers/todo";
import Auth from "./containers/auth";
import TodoRedux from "./containers/todoRedux";
import ThunkTodo from "./containers/thunkTodo";
import { Hooks } from "./containers/hooks";

import { LocalContext, setLanguage } from "./utils/localContext";
import { setCssVariables } from "./utils/setSCCvariables";
import { GLOBAL_DEFAULT_THEME } from "./contants";

import { PrivateRouter } from "./privateRouter";
import { decodeJWT } from "./utils/checkJWTToken";

export const ROUTERS = [
	{
		id: 1,
		link: {
			path: "/",
			title: "Main"
		},
		hasAccess: [0, 1],
		exact: true,
		path: "/",
		protected: true,
		component: Main
	},
	{
		id: 2,
		link: {
			path: "/auth",
			title: "Auth"
		},
		hasAccess: [0, 1],
		exact: true,
		path: "/auth",
		protected: false,
		component: Auth
	},
	{
		id: 3,
		exact: true,
		link: {
			path: "/redux-todo",
			title: "Redux-todo"
		},
		hasAccess: [0, 1],
		path: "/redux-todo",
		protected: false,
		component: TodoRedux
	},
	{
		id: 4,
		link: {
			path: "/todo",
			title: "Todo"
		},
		hasAccess: [0, 1],
		exact: true,
		path: "/todo",
		protected: false,
		component: Todo
	},
	{
		id: 5,
		link: {
			path: "/thunk-todo",
			title: "Thunk TODO"
		},
		hasAccess: [0, 1],
		exact: true,
		path: "/thunk-todo",
		protected: false,
		component: ThunkTodo
	},
	{
		id: 6,
		link: null,
		exact: true,
		hasAccess: [0, 1],
		path: "/item/:id",
		protected: false,
		component: Item
	},
	{
		id: 7,
		link: {
			path: "/hooks",
			title: "Hooks"
		},
		hasAccess: [1],
		exact: true,
		path: "/hooks",
		protected: true,
		component: Hooks
	},
	{
		id: 8,
		link: {
			path: "/about-us",
			title: "About us"
		},
		hasAccess: [0, 1],
		exact: true,
		path: "/about-us",
		protected: true,
		component: AboutUs
	},
	{
		id: 9,
		hasAccess: [0, 1],
		exact: true,
		protected: false,
		component: () => <div>Page not found</div>
	}
];

class Router extends React.Component {
	constructor(props) {
		super(props);

		const themeFromLocalStorage = localStorage.getItem("theme");

		this.state = {
			lang: navigator.language,
			langJson: setLanguage(navigator.language),
			theme: themeFromLocalStorage || GLOBAL_DEFAULT_THEME
		};

		setCssVariables(themeFromLocalStorage ? themeFromLocalStorage : GLOBAL_DEFAULT_THEME);
	}

	setLanguage = lang => {
		this.setState({ lang, langJson: setLanguage(lang) });
	};

	setTheme = theme => {
		setCssVariables(theme);
		this.setState({ theme });
		localStorage.setItem("theme", theme);
	};

	componentDidMount() {
		const token = localStorage.getItem("token");

		if (token) {
			const { id } = decodeJWT(token);
			this.props.getUserByIdRequest({ id, token });
		}
	}

	render() {
		return (
			<LocalContext.Provider
				value={{
					lang: this.state.lang,
					json: this.state.langJson,
					setLanguage: this.setLanguage,
					setCssVariables: this.setTheme,
					theme: this.state.theme
				}}>
				<Switch>
					{ROUTERS.map(route => (
						<PrivateRouter
							key={route.id}
							exact={route.exact}
							path={route.path}
							protectedRoute={route.protected}
							component={route.component}
							hasAccess={route.hasAccess}
						/>
					))}
				</Switch>
			</LocalContext.Provider>
		);
	}
}

export default connect(
	null,
	{ getUserByIdRequest }
)(Router);
